@@ -8,18 +8,18 @@ use super::{
 };
 use crate::{
   build::Options as BuildOptions,
+  error::Context,
   helpers::{
     app_paths::tauri_dir,
     config::{get as get_tauri_config, ConfigHandle},
     flock,
   },
   interface::{AppInterface, Interface, Options as InterfaceOptions},
-  mobile::{write_options, CliOptions},
-  ConfigValue, Result,
+  mobile::{android::generate_tauri_properties, write_options, CliOptions, TargetDevice},
+  ConfigValue, Error, Result,
 };
 use clap::{ArgAction, Parser};
 
-use anyhow::Context;
 use cargo_mobile2::{
   android::{aab, apk, config::Config as AndroidConfig, env::Env, target::Target},
   opts::{NoiseLevel, Profile},
@@ -63,10 +63,10 @@ pub struct Options {
   pub split_per_abi: bool,
   /// Build APKs.
   #[clap(long)]
-  pub apk: bool,
+  pub apk: Option<bool>,
   /// Build AABs.
   #[clap(long)]
-  pub aab: bool,
+  pub aab: Option<bool>,
   /// Open Android Studio
   #[clap(short, long)]
   pub open: bool,
@@ -83,6 +83,9 @@ pub struct Options {
   /// Only use this when you are sure the mismatch is incorrectly detected as version mismatched Tauri packages can lead to unknown behavior.
   #[clap(long)]
   pub ignore_version_mismatches: bool,
+  /// Target device of this build
+  #[clap(skip)]
+  pub target_device: Option<TargetDevice>,
 }
 
 impl From<Options> for BuildOptions {
@@ -99,11 +102,20 @@ impl From<Options> for BuildOptions {
       ci: options.ci,
       skip_stapling: false,
       ignore_version_mismatches: options.ignore_version_mismatches,
+      no_sign: false,
     }
   }
 }
 
-pub fn command(options: Options, noise_level: NoiseLevel) -> Result<()> {
+pub struct BuiltApplication {
+  pub config: AndroidConfig,
+  pub interface: AppInterface,
+  // prevent drop
+  #[allow(dead_code)]
+  options_handle: OptionsHandle,
+}
+
+pub fn command(options: Options, noise_level: NoiseLevel) -> Result<BuiltApplication> {
   crate::helpers::app_paths::resolve();
 
   delete_codegen_vars();
@@ -153,18 +165,25 @@ pub fn command(options: Options, noise_level: NoiseLevel) -> Result<()> {
   };
 
   let tauri_path = tauri_dir();
-  set_current_dir(tauri_path).with_context(|| "failed to change current working directory")?;
+  set_current_dir(tauri_path).context("failed to set current directory to Tauri directory")?;
 
   ensure_init(
     &tauri_config,
     config.app(),
     config.project_dir(),
     MobileTarget::Android,
+    options.ci,
   )?;
 
-  let mut env = env()?;
+  let mut env = env(options.ci)?;
   configure_cargo(&mut env, &config)?;
 
+  generate_tauri_properties(
+    &config,
+    tauri_config.lock().unwrap().as_ref().unwrap(),
+    false,
+  )?;
+
   crate::build::setup(&interface, &mut build_options, tauri_config.clone(), true)?;
 
   let installed_targets =
@@ -174,14 +193,20 @@ pub fn command(options: Options, noise_level: NoiseLevel) -> Result<()> {
     log::info!("Installing target {}", first_target.triple());
     first_target
       .install()
-      .context("failed to install target with rustup")?;
+      .map_err(|error| Error::CommandFailed {
+        command: "rustup target add".to_string(),
+        error,
+      })
+      .context("failed to install target")?;
   }
   // run an initial build to initialize plugins
-  first_target.build(&config, &metadata, &env, noise_level, true, profile)?;
+  first_target
+    .build(&config, &metadata, &env, noise_level, true, profile)
+    .context("failed to build Android app")?;
 
   let open = options.open;
-  let _handle = run_build(
-    interface,
+  let options_handle = run_build(
+    &interface,
     options,
     build_options,
     tauri_config,
@@ -195,12 +220,16 @@ pub fn command(options: Options, noise_level: NoiseLevel) -> Result<()> {
     open_and_wait(&config, &env);
   }
 
-  Ok(())
+  Ok(BuiltApplication {
+    config,
+    interface,
+    options_handle,
+  })
 }
 
 #[allow(clippy::too_many_arguments)]
 fn run_build(
-  interface: AppInterface,
+  interface: &AppInterface,
   mut options: Options,
   build_options: BuildOptions,
   tauri_config: ConfigHandle,
@@ -209,10 +238,10 @@ fn run_build(
   env: &mut Env,
   noise_level: NoiseLevel,
 ) -> Result<OptionsHandle> {
-  if !(options.apk || options.aab) {
+  if !(options.apk.is_some() || options.aab.is_some()) {
     // if the user didn't specify the format to build, we'll do both
-    options.apk = true;
-    options.aab = true;
+    options.apk = Some(true);
+    options.aab = Some(true);
   }
 
   let interface_options = InterfaceOptions {
@@ -233,13 +262,13 @@ fn run_build(
     noise_level,
     vars: Default::default(),
     config: build_options.config,
-    target_device: None,
+    target_device: options.target_device.clone(),
   };
   let handle = write_options(tauri_config.lock().unwrap().as_ref().unwrap(), cli_options)?;
 
   inject_resources(config, tauri_config.lock().unwrap().as_ref().unwrap())?;
 
-  let apk_outputs = if options.apk {
+  let apk_outputs = if options.apk.unwrap_or_default() {
     apk::build(
       config,
       env,
@@ -247,12 +276,13 @@ fn run_build(
       profile,
       get_targets_or_all(options.targets.clone().unwrap_or_default())?,
       options.split_per_abi,
-    )?
+    )
+    .context("failed to build APK")?
   } else {
     Vec::new()
   };
 
-  let aab_outputs = if options.aab {
+  let aab_outputs = if options.aab.unwrap_or_default() {
     aab::build(
       config,
       env,
@@ -260,13 +290,18 @@ fn run_build(
       profile,
       get_targets_or_all(options.targets.unwrap_or_default())?,
       options.split_per_abi,
-    )?
+    )
+    .context("failed to build AAB")?
   } else {
     Vec::new()
   };
 
-  log_finished(apk_outputs, "APK");
-  log_finished(aab_outputs, "AAB");
+  if !apk_outputs.is_empty() {
+    log_finished(apk_outputs, "APK");
+  }
+  if !aab_outputs.is_empty() {
+    log_finished(aab_outputs, "AAB");
+  }
 
   Ok(handle)
 }
@@ -284,12 +319,8 @@ fn get_targets_or_all<'a>(targets: Vec<String>) -> Result<Vec<&'a Target<'a>>> {
       .join(",");
 
     for t in targets {
-      let target = Target::for_name(&t).ok_or_else(|| {
-        anyhow::anyhow!(
-          "Target {} is invalid; the possible targets are {}",
-          t,
-          possible_targets
-        )
+      let target = Target::for_name(&t).with_context(|| {
+        format!("Target {t} is invalid; the possible targets are {possible_targets}",)
       })?;
       outs.push(target);
     }
