@@ -19,6 +19,7 @@ use cargo_mobile2::{
   util::{prompt, relativize_path},
 };
 use clap::{Parser, Subcommand};
+use serde::Deserialize;
 use sublime_fuzzy::best_match;
 use tauri_utils::resources::ResourcePaths;
 
@@ -27,12 +28,13 @@ use super::{
   OptionsHandle, Target as MobileTarget, MIN_DEVICE_MATCH_SCORE,
 };
 use crate::{
+  error::{Context, ErrorExt},
   helpers::{
     app_paths::tauri_dir,
     config::{BundleResources, Config as TauriConfig, ConfigHandle},
     pbxproj, strip_semver_prerelease_tag,
   },
-  ConfigValue, Result,
+  ConfigValue, Error, Result,
 };
 
 use std::{
@@ -47,6 +49,7 @@ use std::{
 mod build;
 mod dev;
 pub(crate) mod project;
+mod run;
 mod xcode_script;
 
 pub const APPLE_DEVELOPMENT_TEAM_ENV_VAR_NAME: &str = "APPLE_DEVELOPMENT_TEAM";
@@ -93,6 +96,7 @@ enum Commands {
   Init(InitOptions),
   Dev(dev::Options),
   Build(build::Options),
+  Run(run::Options),
   #[clap(hide(true))]
   XcodeScript(xcode_script::Options),
 }
@@ -111,7 +115,8 @@ pub fn command(cli: Cli, verbosity: u8) -> Result<()> {
       )?
     }
     Commands::Dev(options) => dev::command(options, noise_level)?,
-    Commands::Build(options) => build::command(options, noise_level)?,
+    Commands::Build(options) => build::command(options, noise_level).map(|_| ())?,
+    Commands::Run(options) => run::command(options, noise_level)?,
     Commands::XcodeScript(options) => xcode_script::command(options)?,
   }
 
@@ -222,7 +227,7 @@ pub fn get_config(
             }
             1 => None,
             _ => {
-              log::warn!("You must set the code signing certificate development team ID on  the `bundle > iOS > developmentTeam` config value or the `{APPLE_DEVELOPMENT_TEAM_ENV_VAR_NAME}` environment variable. Available certificates: {}", teams.iter().map(|t| format!("{} (ID: {})", t.name, t.id)).collect::<Vec<String>>().join(", "));
+              log::warn!("You must set the code signing certificate development team ID on the `bundle > iOS > developmentTeam` config value or the `{APPLE_DEVELOPMENT_TEAM_ENV_VAR_NAME}` environment variable. Available certificates: {}", teams.iter().map(|t| format!("{} (ID: {})", t.name, t.id)).collect::<Vec<String>>().join(", "));
               None
             }
           }
@@ -233,7 +238,8 @@ pub fn get_config(
     ios_version: Some(tauri_config.bundle.ios.minimum_system_version.clone()),
     ..Default::default()
   };
-  let config = AppleConfig::from_raw(app.clone(), Some(raw))?;
+  let config = AppleConfig::from_raw(app.clone(), Some(raw))
+    .context("failed to create Apple configuration")?;
 
   let tauri_dir = tauri_dir();
 
@@ -286,8 +292,9 @@ pub fn get_config(
 }
 
 fn connected_device_prompt<'a>(env: &'_ Env, target: Option<&str>) -> Result<Device<'a>> {
-  let device_list = device::list_devices(env)
-    .map_err(|cause| anyhow::anyhow!("Failed to detect connected iOS devices: {cause}"))?;
+  let device_list = device::list_devices(env).map_err(|cause| {
+    Error::GenericError(format!("Failed to detect connected iOS devices: {cause}"))
+  })?;
   if !device_list.is_empty() {
     let device = if let Some(t) = target {
       let (device, score) = device_list
@@ -303,7 +310,7 @@ fn connected_device_prompt<'a>(env: &'_ Env, target: Option<&str>) -> Result<Dev
       if score > MIN_DEVICE_MATCH_SCORE {
         device
       } else {
-        anyhow::bail!("Could not find an iOS device matching {t}")
+        crate::error::bail!("Could not find an iOS device matching {t}")
       }
     } else {
       let index = if device_list.len() > 1 {
@@ -314,7 +321,7 @@ fn connected_device_prompt<'a>(env: &'_ Env, target: Option<&str>) -> Result<Dev
           None,
           "Device",
         )
-        .map_err(|cause| anyhow::anyhow!("Failed to prompt for iOS device: {cause}"))?
+        .context("failed to prompt for device")?
       } else {
         0
       };
@@ -325,15 +332,28 @@ fn connected_device_prompt<'a>(env: &'_ Env, target: Option<&str>) -> Result<Dev
       device,
       device.target().triple,
     );
+
     Ok(device)
   } else {
-    Err(anyhow::anyhow!("No connected iOS devices detected"))
+    crate::error::bail!("No connected iOS devices detected")
   }
 }
 
+#[derive(Default, Deserialize)]
+struct InstalledRuntimesList {
+  runtimes: Vec<InstalledRuntime>,
+}
+
+#[derive(Deserialize)]
+struct InstalledRuntime {
+  name: String,
+}
+
 fn simulator_prompt(env: &'_ Env, target: Option<&str>) -> Result<device::Simulator> {
   let simulator_list = device::list_simulators(env).map_err(|cause| {
-    anyhow::anyhow!("Failed to detect connected iOS Simulator devices: {cause}")
+    Error::GenericError(format!(
+      "Failed to detect connected iOS Simulator devices: {cause}"
+    ))
   })?;
   if !simulator_list.is_empty() {
     let device = if let Some(t) = target {
@@ -350,7 +370,7 @@ fn simulator_prompt(env: &'_ Env, target: Option<&str>) -> Result<device::Simula
       if score > MIN_DEVICE_MATCH_SCORE {
         device
       } else {
-        anyhow::bail!("Could not find an iOS Simulator matching {t}")
+        crate::error::bail!("Could not find an iOS Simulator matching {t}")
       }
     } else if simulator_list.len() > 1 {
       let index = prompt::list(
@@ -360,14 +380,31 @@ fn simulator_prompt(env: &'_ Env, target: Option<&str>) -> Result<device::Simula
         None,
         "Simulator",
       )
-      .map_err(|cause| anyhow::anyhow!("Failed to prompt for iOS Simulator device: {cause}"))?;
+      .context("failed to prompt for simulator")?;
       simulator_list.into_iter().nth(index).unwrap()
     } else {
       simulator_list.into_iter().next().unwrap()
     };
     Ok(device)
   } else {
-    Err(anyhow::anyhow!("No available iOS Simulator detected"))
+    log::warn!("No available iOS Simulator detected");
+    let install_ios = crate::helpers::prompts::confirm(
+      "Would you like to install the latest iOS runtime?",
+      Some(false),
+    )
+    .unwrap_or_default();
+    if install_ios {
+      duct::cmd("xcodebuild", ["-downloadPlatform", "iOS"])
+        .stdout_file(os_pipe::dup_stdout().unwrap())
+        .stderr_file(os_pipe::dup_stderr().unwrap())
+        .run()
+        .map_err(|e| Error::CommandFailed {
+          command: "xcodebuild -downloadPlatform iOS".to_string(),
+          error: e,
+        })?;
+      return simulator_prompt(env, target);
+    }
+    crate::error::bail!("No available iOS Simulator detected")
   }
 }
 
@@ -377,11 +414,49 @@ fn device_prompt<'a>(env: &'_ Env, target: Option<&str>) -> Result<Device<'a>> {
   } else {
     let simulator = simulator_prompt(env, target)?;
     log::info!("Starting simulator {}", simulator.name());
-    simulator.start_detached(env)?;
+    simulator
+      .start_detached(env)
+      .context("failed to start simulator")?;
     Ok(simulator.into())
   }
 }
 
+fn ensure_ios_runtime_installed() -> Result<()> {
+  let installed_platforms_json = duct::cmd("xcrun", ["simctl", "list", "runtimes", "--json"])
+    .read()
+    .map_err(|e| Error::CommandFailed {
+      command: "xcrun simctl list runtimes --json".to_string(),
+      error: e,
+    })?;
+  let installed_platforms: InstalledRuntimesList =
+    serde_json::from_str(&installed_platforms_json).unwrap_or_default();
+  if !installed_platforms
+    .runtimes
+    .iter()
+    .any(|r| r.name.starts_with("iOS"))
+  {
+    log::warn!("iOS platform not installed");
+    let install_ios = crate::helpers::prompts::confirm(
+      "Would you like to install the latest iOS runtime?",
+      Some(false),
+    )
+    .unwrap_or_default();
+    if install_ios {
+      duct::cmd("xcodebuild", ["-downloadPlatform", "iOS"])
+        .stdout_file(os_pipe::dup_stdout().unwrap())
+        .stderr_file(os_pipe::dup_stderr().unwrap())
+        .run()
+        .map_err(|e| Error::CommandFailed {
+          command: "xcodebuild -downloadPlatform iOS".to_string(),
+          error: e,
+        })?;
+    } else {
+      crate::error::bail!("iOS platform not installed");
+    }
+  }
+  Ok(())
+}
+
 fn detect_target_ok<'a>(env: &Env) -> Option<&'a Target<'a>> {
   device_prompt(env, None).map(|device| device.target()).ok()
 }
@@ -398,7 +473,7 @@ fn open_and_wait(config: &AppleConfig, env: &Env) -> ! {
 
 fn inject_resources(config: &AppleConfig, tauri_config: &TauriConfig) -> Result<()> {
   let asset_dir = config.project_dir().join(DEFAULT_ASSET_DIR);
-  create_dir_all(&asset_dir)?;
+  create_dir_all(&asset_dir).fs_context("failed to create asset directory", asset_dir.clone())?;
 
   let resources = match &tauri_config.bundle.resources {
     Some(BundleResources::List(paths)) => Some(ResourcePaths::new(paths.as_slice(), true)),
@@ -407,7 +482,7 @@ fn inject_resources(config: &AppleConfig, tauri_config: &TauriConfig) -> Result<
   };
   if let Some(resources) = resources {
     for resource in resources.iter() {
-      let resource = resource?;
+      let resource = resource.context("failed to get resource")?;
       let dest = asset_dir.join(resource.target());
       crate::helpers::fs::copy_file(resource.path(), dest)?;
     }
@@ -416,42 +491,6 @@ fn inject_resources(config: &AppleConfig, tauri_config: &TauriConfig) -> Result<
   Ok(())
 }
 
-enum PlistKind {
-  Path(PathBuf),
-  Plist(plist::Value),
-}
-
-impl From<PathBuf> for PlistKind {
-  fn from(p: PathBuf) -> Self {
-    Self::Path(p)
-  }
-}
-impl From<plist::Value> for PlistKind {
-  fn from(p: plist::Value) -> Self {
-    Self::Plist(p)
-  }
-}
-
-fn merge_plist(src: Vec<PlistKind>) -> Result<plist::Value> {
-  let mut merged_plist = plist::Dictionary::new();
-
-  for plist_kind in src {
-    let plist = match plist_kind {
-      PlistKind::Path(p) => plist::Value::from_file(p),
-      PlistKind::Plist(v) => Ok(v),
-    };
-    if let Ok(src_plist) = plist {
-      if let Some(dict) = src_plist.into_dictionary() {
-        for (key, value) in dict {
-          merged_plist.insert(key, value);
-        }
-      }
-    }
-  }
-
-  Ok(plist::Value::Dictionary(merged_plist))
-}
-
 pub fn signing_from_env() -> Result<(
   Option<tauri_macos_sign::Keychain>,
   Option<tauri_macos_sign::ProvisioningProfile>,
@@ -462,7 +501,9 @@ pub fn signing_from_env() -> Result<(
   ) {
     (Some(certificate), Some(certificate_password)) => {
       log::info!("Reading iOS certificates from ");
-      tauri_macos_sign::Keychain::with_certificate(&certificate, &certificate_password).map(Some)?
+      tauri_macos_sign::Keychain::with_certificate(&certificate, &certificate_password)
+        .map(Some)
+        .map_err(Box::new)?
     }
     (Some(_), None) => {
       log::warn!("The IOS_CERTIFICATE environment variable is set but not IOS_CERTIFICATE_PASSWORD. Ignoring the certificate...");
@@ -472,7 +513,9 @@ pub fn signing_from_env() -> Result<(
   };
 
   let provisioning_profile = if let Some(provisioning_profile) = var_os("IOS_MOBILE_PROVISION") {
-    tauri_macos_sign::ProvisioningProfile::from_base64(&provisioning_profile).map(Some)?
+    tauri_macos_sign::ProvisioningProfile::from_base64(&provisioning_profile)
+      .map(Some)
+      .map_err(Box::new)?
   } else {
     if keychain.is_some() {
       log::warn!("You have provided an iOS certificate via environment variables but the IOS_MOBILE_PROVISION environment variable is not set. This will fail when signing unless the profile is set in your Xcode project.");
