@@ -157,11 +157,12 @@ mod window_effects {
 pub use window_effects::{WindowEffect, WindowEffectState};
 
 /// How the window title bar should be displayed on macOS.
-#[derive(Debug, Clone, PartialEq, Eq, Copy)]
+#[derive(Debug, Clone, PartialEq, Eq, Copy, Default)]
 #[cfg_attr(feature = "schema", derive(schemars::JsonSchema))]
 #[non_exhaustive]
 pub enum TitleBarStyle {
   /// A normal title bar.
+  #[default]
   Visible,
   /// Makes the title bar transparent, so the window background color is shown instead.
   ///
@@ -176,12 +177,6 @@ pub enum TitleBarStyle {
   Overlay,
 }
 
-impl Default for TitleBarStyle {
-  fn default() -> Self {
-    Self::Visible
-  }
-}
-
 impl Serialize for TitleBarStyle {
   fn serialize<S>(&self, serializer: S) -> std::result::Result<S::Ok, S::Error>
   where
