@@ -13,7 +13,7 @@ window.addEventListener('keydown', (event) => {
   if (OS_NAME === 'macos' ? event.metaKey : event.ctrlKey) {
     if (event.key === '-') {
       zoomLevel -= 0.2
-    } else if (event.key === '=') {
+    } else if (event.key === '=' || event.key === '+') {
       zoomLevel += 0.2
     } else if (event.key === '0') {
       zoomLevel = 1
@@ -26,3 +26,18 @@ window.addEventListener('keydown', (event) => {
     })
   }
 })
+
+window.addEventListener('mousewheel', (event) => {
+  if (event.ctrlKey) {
+    event.preventDefault()
+    if (event.deltaY < 0) {
+      zoomLevel += 0.2
+    } else {
+      zoomLevel -= 0.2
+    }
+    zoomLevel = Math.min(Math.max(zoomLevel, MIN_ZOOM_LEVEL), MAX_ZOOM_LEVEL)
+    window.__TAURI_INTERNALS__.invoke('plugin:webview|set_webview_zoom', {
+      value: zoomLevel
+    })
+  }
+})
